summaryrefslogtreecommitdiff
path: root/sys/arch/hp300/stand
diff options
context:
space:
mode:
authorMiod Vallat <miod@cvs.openbsd.org>2006-08-13 16:41:45 +0000
committerMiod Vallat <miod@cvs.openbsd.org>2006-08-13 16:41:45 +0000
commit3f57aa97954a50188b399bf7b07c5758bb1f5115 (patch)
tree53a4c969b8b78a4e16490f88e516fa321cf910bc /sys/arch/hp300/stand
parent20acae0e6dc2c0e71960a48197ecb16adfa4425f (diff)
Let the domain keyboard work on models 362 and 382 as well.
Diffstat (limited to 'sys/arch/hp300/stand')
-rw-r--r--sys/arch/hp300/stand/common/dnkbd.c7
1 files changed, 5 insertions, 2 deletions
diff --git a/sys/arch/hp300/stand/common/dnkbd.c b/sys/arch/hp300/stand/common/dnkbd.c
index 4215cca89e6..87a1a1eca08 100644
--- a/sys/arch/hp300/stand/common/dnkbd.c
+++ b/sys/arch/hp300/stand/common/dnkbd.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: dnkbd.c,v 1.2 2003/09/26 21:43:28 miod Exp $ */
+/* $OpenBSD: dnkbd.c,v 1.3 2006/08/13 16:41:44 miod Exp $ */
/* $NetBSD: dnkbd.c,v 1.3 1997/05/12 07:47:03 thorpej Exp $ */
/*-
@@ -160,9 +160,12 @@ dnkbd_init()
{
/*
* 400, 425, and 433 models can have a Domain keyboard.
*/
switch (machineid) {
+ case HP_360:
+ case HP_382:
case HP_400:
case HP_425:
case HP_433:
@@ -160,9 +160,12 @@ dnkbd_init()
{
/*
- * 400, 425, and 433 models can have a Domain keyboard.
+ * 362, 382, 400, 425, and 433 models can have a Domain keyboard.
+ * Note that we do not tell 360 from 362 in the bootblocks.
*/
switch (machineid) {